@@ -1,18 +1,23 @@
-/* 
- * Copyright 2017 Hadrien Mary.
- *
+/*-
+ * #%L
+ * SciJava polyglot kernel for Jupyter.
+ * %%
+ * Copyright (C) 2017 Hadrien Mary
+ * %%
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- *
+ * 
  *      http://www.apache.org/licenses/LICENSE-2.0
- *
+ * 
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ * #L%
  */
+
 package org.scijava.jupyter.kernel.evaluator;
 
 import com.twosigma.beaker.autocomplete.AutocompleteResult;
@@ -25,6 +30,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+
 import javax.script.Bindings;
 import javax.script.ScriptContext;
 import javax.script.ScriptEngine;
@@ -32,6 +38,8 @@ import javax.script.ScriptEngine;
 import org.scijava.Context;
 import org.scijava.log.LogService;
 import org.scijava.plugin.Parameter;
+import org.scijava.script.AutoCompleter;
+import org.scijava.script.AutoCompletionResult;
 import org.scijava.script.ScriptLanguage;
 import org.scijava.script.ScriptService;
 import org.scijava.thread.ThreadService;
@@ -58,6 +66,7 @@ public class ScijavaEvaluator implements Evaluator {
 
     private final Map<String, ScriptEngine> scriptEngines;
     private final Map<String, ScriptLanguage> scriptLanguages;
+    private final Map<String, AutoCompleter> completers;
     private String languageName;
 
     protected String shellId;
@@ -71,6 +80,8 @@ public class ScijavaEvaluator implements Evaluator {
 
         this.scriptEngines = new HashMap<>();
         this.scriptLanguages = new HashMap<>();
+        
+        this.completers = new HashMap<>();
 
         this.languageName = DEFAULT_LANGUAGE;
     }
@@ -81,12 +92,19 @@ public class ScijavaEvaluator implements Evaluator {
     }
 
     @Override
-    public AutocompleteResult autocomplete(String code, int i) {
-        List<String> matches = new ArrayList<>();
-        matches.add("Autocompletion does not work yet.");
-        int startIndex = 0;
-        AutocompleteResult ac = new AutocompleteResult(matches, startIndex);
-        return ac;
+    public AutocompleteResult autocomplete(String code, int index) {
+        
+        // TODO: we need to find a way the language related to the current cell.
+        // For now, we are just using the last used language.
+        AutoCompleter completer = this.completers.get(this.languageName);
+        ScriptEngine scriptEngine = this.scriptEngines.get(this.languageName);
+
+        AutoCompletionResult result = completer.autocomplete(code, index, scriptEngine);
+
+        List<String> matches = (List<String>) result.getMatches();
+        int startIndex = (int) result.getStartIndex();
+
+        return new AutocompleteResult(matches, startIndex);
     }
 
     @Override
@@ -108,7 +126,7 @@ public class ScijavaEvaluator implements Evaluator {
 
         Worker worker = new Worker(this.context, this.scriptEngines, this.scriptLanguages);
         worker.setup(seo, code, this.languageName);
-        this.threadService.queue(worker);
+        this.threadService.queue(getClass().getName(), worker);
     }
 
     @Override
@@ -118,14 +136,14 @@ public class ScijavaEvaluator implements Evaluator {
         System.exit(0);
     }
 
-    private void addLanguage(String languageName) {
+    private void addLanguage(String langName) {
 
-        if (scriptService.getLanguageByName(languageName) == null) {
-            log.error("Script Language for '" + languageName + "' not found.");
+        if (scriptService.getLanguageByName(langName) == null) {
+            log.error("Script Language for '" + langName + "' not found.");
             System.exit(1);
         }
 
-        if (!this.scriptLanguages.keySet().contains(languageName)) {
+        if (!this.scriptLanguages.keySet().contains(langName)) {
 
             Bindings bindings = null;
             if (!this.scriptEngines.isEmpty()) {
@@ -133,12 +151,15 @@ public class ScijavaEvaluator implements Evaluator {
                 bindings = this.scriptEngines.get(firstLanguage).getBindings(ScriptContext.ENGINE_SCOPE);
             }
 
-            log.info("Script Language for '" + languageName + "' found.");
-            ScriptLanguage scriptLanguage = scriptService.getLanguageByName(languageName);
-            this.scriptLanguages.put(languageName, scriptLanguage);
+            log.info("Script Language for '" + langName + "' found.");
+            ScriptLanguage scriptLanguage = scriptService.getLanguageByName(langName);
+            this.scriptLanguages.put(langName, scriptLanguage);
 
-            ScriptEngine engine = this.scriptLanguages.get(languageName).getScriptEngine();
-            this.scriptEngines.put(languageName, engine);
+            ScriptEngine engine = this.scriptLanguages.get(langName).getScriptEngine();
+            this.scriptEngines.put(langName, engine);
+            
+            AutoCompleter completer = scriptLanguage.getAutoCompleter();
+            this.completers.put(languageName, completer);
 
             // Not implemented yet
             //engine.setBindings(this.bindings, ScriptContext.ENGINE_SCOPE);
@@ -148,7 +169,7 @@ public class ScijavaEvaluator implements Evaluator {
 
         }
 
-        log.debug("Script Language found for '" + languageName + "'");
+        log.debug("Script Language found for '" + langName + "'");
     }
 
     private String setLanguage(String code) {
