@@ -1,33 +1,37 @@
-/* 
- * Copyright 2017 Hadrien Mary.
- *
+/*-
+ * #%L
+ * SciJava polyglot kernel for Jupyter.
+ * %%
+ * Copyright (C) 2017 Hadrien Mary
+ * %%
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- *
+ * 
  *      http://www.apache.org/licenses/LICENSE-2.0
- *
+ * 
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ * #L%
  */
+
 package org.scijava.jupyter.kernel.handler;
 
 import static com.twosigma.beaker.jupyter.msg.JupyterMessages.KERNEL_INFO_REPLY;
+import static com.twosigma.jupyter.handler.KernelHandlerWrapper.wrapBusyIdle;
+
+import com.twosigma.jupyter.KernelFunctionality;
+import com.twosigma.jupyter.handler.KernelHandler;
+import com.twosigma.jupyter.message.Header;
+import com.twosigma.jupyter.message.Message;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.HashMap;
-
-import com.twosigma.jupyter.KernelFunctionality;
-import com.twosigma.jupyter.handler.KernelHandler;
-import static com.twosigma.jupyter.handler.KernelHandlerWrapper.wrapBusyIdle;
-import com.twosigma.jupyter.message.Header;
-import com.twosigma.jupyter.message.Message;
 import java.util.List;
-import org.scijava.script.ScriptLanguage;
 
 /**
  *
